@@ -12,8 +12,14 @@ from django.utils.encoding import smart_unicode, force_unicode
 from django.utils.html import escape, conditional_escape
 from django.utils.safestring import mark_safe
 
+from categories.editor import settings
+
 register = Library()
 
+TREE_LIST_RESULTS_TEMPLATE = 'admin/editor/tree_list_results.html'
+if settings.IS_GRAPPELLI_INSTALLED:
+    TREE_LIST_RESULTS_TEMPLATE = 'admin/editor/grappelli_tree_list_results.html'
+
 
 def items_for_tree_result(cl, result, form):
     """
@@ -145,4 +151,4 @@ def result_tree_list(cl):
         from django.contrib.admin.templatetags.admin_list import result_hidden_fields
         result['result_hidden_fields'] = list(result_hidden_fields(cl))
     return result
-result_tree_list = register.inclusion_tag("admin/editor/tree_list_results.html")(result_tree_list)
+result_tree_list = register.inclusion_tag(TREE_LIST_RESULTS_TEMPLATE)(result_tree_list)
