@@ -46,7 +46,7 @@ def get_category(category_string, model=Category):
     Convert a string, including a path, and return the Category object
     """
     model_class = get_cat_model(model)
-    category = category_string.strip("'\"")
+    category = str(category_string).strip("'\"")
     category = category.strip('/')
 
     cat_list = category.split('/')
@@ -184,7 +184,10 @@ def display_drilldown_as_ul(category, using='categories.Category'):
         </ul>
     """
     cat = get_category(category, using)
-    return {'category': cat, 'path': drilldown_tree_for_node(cat) or []}
+    if cat is None:
+        return {'category': cat, 'path': []}
+    else:                          
+        return {'category': cat, 'path': drilldown_tree_for_node(cat)}
 
 
 @register.inclusion_tag('categories/ul_tree.html')
